"""
Program file: mondrian.py

Draws an abstract painting after the style of Piet Mondrian.
"""

from turtle import *
from random import randint

# Data to track performance
stats = {"calls":0, "rectangles":0}

def randomColor():
    "Returns a random RGB color."
    return (randint(0, 255), randint(0, 255), randint(0, 255))

def drawRectangle(x1, y1, x2, y2):
    """Draws a rectangle with the given corner points
    using a random color."""
    stats["rectangles"] = stats["rectangles"] + 1
    (red, green, blue) = randomColor()
    pencolor(red, green, blue)
    up()
    goto(x1, y1)
    down()
    goto(x2, y1)
    goto(x2, y2)
    goto(x1, y2)
    goto(x1, y1)
    
def mondrian(x1, y1, x2, y2, level):
    """Draws a Mondrian-like painting at the given level."""
    stats["calls"] = stats["calls"] + 1
    if level > 0:
        drawRectangle(x1, y1, x2, y2)
        vertical = randint(1, 2)
        if vertical == 1:   # Vertical split
            mondrian(x1, y1, (x2 - x1) / 3 + x1, y2,
                     level - 1)
            mondrian((x2 - x1) / 3 + x1, y1, x2, y2, 
                     level - 1)

        else:               # Horizontal split

            mondrian(x1, y1, x2, y1 - (y1 - y2) / 3, 
                     level - 1)
            mondrian(x1, y1 - (y1 - y2) / 3, x2, y2, 
                     level - 1)

def main():
    # Reset stats on each call of main.
    stats["calls"] = 0
    stats["rectangles"] = 0
    # Obtain the level from the user.
    level = numinput("Input Dialog", "Enter the level",
                      default = 1, minval = 1)
    if not level:
        level = 1
    paintingWidth = window_width() // 2 - 20    # Offset within edge of 
    paintingHeight = window_height() // 2 - 20  # window.    
    hideturtle()
    speed(0)
    pensize(2)
    
    # Delay drawing if level is greater than 8.
    if level > 6:        
        tracer(False)
    mondrian(-paintingWidth, paintingHeight,
             paintingWidth, -paintingHeight, level)
    # Draw now if level is greater than 8.
    if level > 6:        
        update()
    print(stats)

if __name__ == "__main__":
    main()
