"""
File: animate3.py
Creates two animated turtles. One bounces back and forth, while
the other revolves in a circular pattern.
"""

from animatedturtle import AnimatedTurtle
from turtle import hideturtle, listen, mainloop, onscreenclick
from turtle import window_height, window_width
from random import randint

def pauseOrResume(turtles):
    """Pauses or resumes the animation."""
    for t in turtles:
        t.animated(not t.animated())
        
def rebound(aTurtle):
    """Callback function that fires on each timer event.
    Moves forward until an edge is encountered, then turns
    about face."""
    if window_height() // 2 - 20 <= abs(aTurtle.ycor())or \
       window_width() // 2 - 20 <= abs(aTurtle.xcor()):
            aTurtle.left(180)
    aTurtle.forward(4)

def twirl(aTurtle):
    """Callback function that fires on each timer event.
    Turns and moves forward, as in a circle."""
    aTurtle.left(8)
    aTurtle.forward(8)

def randomColor():
    """Returns a random RGB value."""
    return (randint(0, 255), randint(0, 255), randint(0, 255))

def main():
    hideturtle()
    sleepy = AnimatedTurtle(heading = 0, fillColor = randomColor(),
                            callback = rebound)
    speedy = AnimatedTurtle(heading = 90, fillColor = randomColor(),
                            callback = twirl)
    turtles = (sleepy, speedy)
    onscreenclick(lambda x, y: pauseOrResume(turtles))
    listen()
    return "Done!"

if __name__ == '__main__':
    msg = main()
    print(msg)
    mainloop()
